from setuptools import setup

setup(
   name='rocket_youcef',
   version='2.0.0',
   author='talbi_youcef',
   author_email='y.talbi@esi-sba.dz',
   packages=['rocket_youcef'],
   url='http://pypi.python.org/pypi/rocket_youcef/',
   license='LICENSE.txt',
   description='`rocket` is a Python library for simulating and manipulating rocket objects, including their movement and different properties.',
   long_description=open("README.md").read(),
   long_description_content_type="text/markdown"
)